@@ -142,15 +142,11 @@ impl Command for UnitCommand {
             .collect::<Vec<_>>();
         Ok(Output {
             title: "Unit Converter".into(),
-            blocks: vec![Block::Data(
-                block::Data::new()
-                    .set_data(format!(
-                        "{} =\n{}",
-                        base_unit.to_string(),
-                        converted.join("\n")
-                    ))
-                    .set_media_type(media_type!(TEXT / PLAIN)),
-            )],
+            blocks: vec![Block::Data(block::Data::new().set_text_data(format!(
+                "{} =\n{}",
+                base_unit.to_string(),
+                converted.join("\n")
+            )))],
         })
     }
 
